import React from 'react';
import '../../css/style.css';
import App from "./App";
import * as d3 from "d3";

class PrixM2 extends React.Component {

  constructor(props){
    super(props);
    this.state = {
      data: []
    }
  }

  getData(){
    fetch(`https://${document.domain}:8443/prix-m2`)
      .then(response => {
        if (response.ok) {
          return response.json();
        } else {
          throw new Error('error');
        }
      })
      .then(data => {
        this.setState({data: data });
      })
      .catch(error => console.log("error"));
  }

  componentDidMount(){
    this.getData();
  }

  render() {
    const data =  this.state.data
    console.log(data)

    const margin = {top: 20, right: 30, bottom: 30, left: 60},
      width = document.getElementById("container").offsetWidth * 0.95 - margin.left - margin.right,
      height = 400 - margin.top - margin.bottom;

    const parseTime = d3.timeParse("%d/%m/%Y");
    const dateFormat = d3.timeFormat("%d/%m/%Y");

    const x = d3.scaleTime()
      .range([0, width]);

    const y = d3.scaleLinear()
      .range([height, 0]);

    console.log(data)
    const line = d3.line()
      .x(d => x(d.month))
      .y(d => y(d.moyenne_surface));

    const svg = d3.select("#chart").append("svg")
      .attr("id", "svg")
      .attr("width", width + margin.left + margin.right)
      .attr("height", height + margin.top + margin.bottom)
      .append("g")
      .attr("transform", "translate(" + margin.left + "," + margin.top + ")");

    var map = {};
    data.forEach(function(d) {
      d.month = parseTime(d.month);
      d.moyenne_surface = +d.moyenne_surface;
      map[d.month] = d; // sauvegarde sous forme de hashmap de nos données.
    });

    x.domain(d3.extent(data, d => d.month ));
    y.domain(d3.extent(data, d => d.moyenne_surface))
    // Ajout de l'axe X
    svg.append("g")
      .attr("transform", "translate(0," + height + ")")
      .call(d3.axisBottom(x));

    // Ajout de l'axe Y et du texte associé pour la légende
    svg.append("g")
      .call(d3.axisLeft(y))
      .append("text")
      .attr("fill", "#000")
      .attr("transform", "rotate(-90)")
      .attr("y", 6)
      .attr("dy", "0.71em")
      .style("text-anchor", "end")
      .text("Pts");

    // Ajout de la grille horizontale (pour l'axe Y donc). Pour chaque tiret (ticks), on ajoute une ligne qui va
    // de la gauche à la droite du graphique et qui se situe à la bonne hauteur.
    svg.selectAll("y axis").data(y.ticks(10)).enter()
      .append("line")
      .attr("class", "horizontalGrid")
      .attr("x1", 0)
      .attr("x2", width)
      .attr("y1", d => y(d))
      .attr("y2", d => y(d));

    // Ajout d'un path calculé par la fonction line à partir des données de notre fichier.
    svg.append("path")
      .datum(data)
      .attr("class", "line")
      .attr("d", line);

    return  (
      <div>
        <App/>
        <h2>Graphs with React</h2>
        <div id="chart">
        </div>
      </div>
    )
  }
}

export default PrixM2;
